@@ -31,7 +31,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 namespace Gwenview {
 
 
-class ConfigDialogPrivate;
+struct ConfigDialogPrivate;
 class ConfigDialog : public KConfigDialog {
 public:
 	ConfigDialog(QWidget* parent);
