@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1997-2002 Richard J. Moore <rich@kde.org>
+ *  Copyright (C) 1997-2008 Richard J. Moore <rich@kde.org>
  *  Copyright (C) 2000 Matthias Ettrich <ettrich@troll.no>
  *  Copyright (C) 2002 Aaron J. Seigo <aseigo@kde.org>
  *  Copyright (C) 2003 Nadeem Hasan <nhasan@kde.org>
@@ -37,7 +37,6 @@
 #include <kimageio.h>
 #include <kcomponentdata.h>
 #include <kfiledialog.h>
-#include <kimagefilepreview.h>
 #include <kmessagebox.h>
 #include <kio/netaccess.h>
 #include <ksavefile.h>
@@ -52,11 +51,13 @@
 #include <kstandarddirs.h>
 #include <kstartupinfo.h>
 #include <kvbox.h>
+#include <qdebug.h>
 
 #include "regiongrabber.h"
 #include "windowgrabber.h"
 #include "ui_ksnapshotwidget.h"
 
+
 class KSnapshotWidget : public QWidget, public Ui::KSnapshotWidget
 {
     public:
@@ -110,8 +111,20 @@ KSnapshot::KSnapshot(QWidget *parent,  KSnapshotObject::CaptureMode mode )
     grabber->show();
     grabber->grabMouse( Qt::WaitCursor );
 
+    qDebug() << "Mode = " << mode;
     if ( mode == KSnapshotObject::FullScreen )
         snapshot = QPixmap::grabWindow( QApplication::desktop()->winId() );
+    else if ( mode == KSnapshotObject::CurrentScreen ) {
+	qDebug() << "Desktop Geom = " << QApplication::desktop()->geometry();
+	QDesktopWidget *desktop = QApplication::desktop();
+	int screenId = desktop->screenNumber( QCursor::pos() );
+	qDebug() << "Screenid = " << screenId;
+	QRect geom = desktop->screenGeometry( screenId );
+	qDebug() << "Geometry = " << screenId;
+	snapshot = QPixmap::grabWindow( desktop->winId(),
+					geom.x(), geom.y(), geom.width(), geom.height() );
+
+    }
     else {
         setMode( mode );
 	switch(mode)
@@ -159,7 +172,7 @@ KSnapshot::KSnapshot(QWidget *parent,  KSnapshotObject::CaptureMode mode )
     connect( &updateTimer, SIGNAL( timeout() ), this, SLOT(  updatePreview() ) );
     QTimer::singleShot( 0, this, SLOT( updateCaption() ) );
 
-    KHelpMenu *helpMenu = new KHelpMenu(this, KGlobal::mainComponent().aboutData(), false);
+    KHelpMenu *helpMenu = new KHelpMenu(this, KGlobal::mainComponent().aboutData(), true);
     setButtonMenu( Help, helpMenu->menu() );
 #if 0
     accel->insert( "QuickSave", i18n("Quick Save Snapshot &As..."),
@@ -216,9 +229,9 @@ void KSnapshot::slotSaveAs()
 
     dlg.setOperationMode( KFileDialog::Saving );
     dlg.setCaption( i18n("Save As") );
+    dlg.setSelection( filename.url() );
 
-    KImageFilePreview *ip = new KImageFilePreview( &dlg );
-    dlg.setPreviewWidget( ip );
+    dlg.setInlinePreviewShown(true);
 
     if ( !dlg.exec() )
         return;
@@ -396,6 +409,8 @@ void KSnapshot::closeEvent( QCloseEvent * e )
     KUrl url = filename;
     url.setPass( QString::null );	//krazy:exclude=nullstrassign for old broken gcc
     conf.writePathEntry("filename",url.url());
+
+    conf.sync();
     e->accept();
 }
 
@@ -440,6 +455,10 @@ void KSnapshot::performGrab()
     grabber->releaseMouse();
     grabber->hide();
     grabTimer.stop();
+
+    title = QString();
+    windowClass = QString();
+
     if ( mode() == ChildWindow ) {
         WindowGrabber wndGrab;
         connect( &wndGrab, SIGNAL( windowGrabbed( const QPixmap & ) ),
@@ -448,6 +467,23 @@ void KSnapshot::performGrab()
     }
     else if ( mode() == WindowUnderCursor ) {
         snapshot = WindowGrabber::grabCurrent( includeDecorations() );
+
+	// If we're showing decorations anyway then we'll add the title and window
+	// class to the output image meta data.
+	if ( includeDecorations() ) {
+	    title = WindowGrabber::lastWindowTitle();
+	    windowClass = WindowGrabber::lastWindowClass();
+	}
+    }
+    else if ( mode() == CurrentScreen ) {
+	kDebug() << "Desktop Geom2 = " << QApplication::desktop()->geometry();
+	QDesktopWidget *desktop = QApplication::desktop();
+	int screenId = desktop->screenNumber( QCursor::pos() );
+	kDebug() << "Screenid2 = " << screenId;
+	QRect geom = desktop->screenGeometry( screenId );
+	kDebug() << "Geometry2 = " << geom;
+	snapshot = QPixmap::grabWindow( desktop->winId(),
+					geom.x(), geom.y(), geom.width(), geom.height() );
     }
     else {
         snapshot = QPixmap::grabWindow( QApplication::desktop()->winId() );
